==> spotbugs-maven-plugin-3.1.3.1-sources.jar: org/codehaus/mojo/spotbugs/SpotbugsReportGenerator.java <==
package org.codehaus.mojo.spotbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SpotbugsReportGenerator
  extends java.lang.Object  implements
    org.codehaus.mojo.spotbugs.SpotBugsInfo,    groovy.lang.GroovyObject {
;
public SpotbugsReportGenerator
(org.apache.maven.doxia.sink.Sink sink, java.util.ResourceBundle bundle, java.io.File basedir, org.apache.maven.doxia.tools.SiteTool siteTool) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.String getNOLINE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_LINE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_BUG_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_BUGS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CATEGORY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_PRIORITY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_DETAILS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getREPORT_TITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getLINKTITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getLINK_KEY() { return (java.lang.String)null;}
public static  java.lang.String getFILES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getTHRESHOLD_KEY() { return (java.lang.String)null;}
public static  java.lang.String getEFFORT_KEY() { return (java.lang.String)null;}
public static  java.lang.String getDETAILSLINK_KEY() { return (java.lang.String)null;}
public static  java.lang.String getVERSIONTITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getSUMMARY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CLASS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CLASSES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_ERRORS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_FILES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_MISSINGCLASSES_KEY() { return (java.lang.String)null;}
public  org.apache.maven.doxia.sink.Sink getSink() { return (org.apache.maven.doxia.sink.Sink)null;}
public  void setSink(org.apache.maven.doxia.sink.Sink value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  org.apache.maven.plugin.logging.Log getLog() { return (org.apache.maven.plugin.logging.Log)null;}
public  void setLog(org.apache.maven.plugin.logging.Log value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.String getCurrentClassName() { return (java.lang.String)null;}
public  void setCurrentClassName(java.lang.String value) { }
public  boolean getmIsCurrentClassReportOpened() { return false;}
public  boolean ismIsCurrentClassReportOpened() { return false;}
public  void setmIsCurrentClassReportOpened(boolean value) { }
public  boolean getIsJXRReportEnabled() { return false;}
public  boolean isIsJXRReportEnabled() { return false;}
public  void setIsJXRReportEnabled(boolean value) { }
public  int getBugCount() { return (int)0;}
public  void setBugCount(int value) { }
public  int getMissingClassCount() { return (int)0;}
public  void setMissingClassCount(int value) { }
public  int getFileCount() { return (int)0;}
public  void setFileCount(int value) { }
public  java.util.Set getMissingClassSet() { return (java.util.Set)null;}
public  void setMissingClassSet(java.util.Set value) { }
public  int getErrorCount() { return (int)0;}
public  void setErrorCount(int value) { }
public  java.io.File getOutputDirectory() { return (java.io.File)null;}
public  void setOutputDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  java.io.File getBasedir() { return (java.io.File)null;}
public  void setBasedir(java.io.File value) { }
public  groovy.util.slurpersupport.GPathResult getSpotbugsResults() { return (groovy.util.slurpersupport.GPathResult)null;}
public  void setSpotbugsResults(groovy.util.slurpersupport.GPathResult value) { }
public  java.util.List getBugClasses() { return (java.util.List)null;}
public  void setBugClasses(java.util.List value) { }
public  void printBody() { }
protected  void printBug(java.lang.String bugClass) { }
protected  java.lang.String assembleJxrHyperlink(groovy.util.slurpersupport.GPathResult line) { return (java.lang.String)null;}
protected  java.lang.String getReportTitle() { return (java.lang.String)null;}
protected  void openClassReportSection(java.lang.String bugClass) { }
protected  void printSummary() { }
protected  void printFilesSummary() { }
public  void generateReport() { }
protected  java.lang.String valueForLine(groovy.util.slurpersupport.GPathResult line) { return (java.lang.String)null;}
}

==> spotbugs-maven-plugin-4.5.3.0-sources.jar: org/codehaus/mojo/spotbugs/SpotbugsReportGenerator.java <==
package org.codehaus.mojo.spotbugs;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

public class SpotbugsReportGenerator
  extends java.lang.Object  implements
    org.codehaus.mojo.spotbugs.SpotBugsInfo,    groovy.lang.GroovyObject {
;
public SpotbugsReportGenerator
(org.apache.maven.doxia.sink.Sink sink, java.util.ResourceBundle bundle, java.io.File basedir, org.apache.maven.doxia.tools.SiteTool siteTool) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.String getNOLINE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_LINE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_BUG_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_BUGS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CATEGORY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_PRIORITY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_DETAILS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getREPORT_TITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getLINKTITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getLINK_KEY() { return (java.lang.String)null;}
public static  java.lang.String getFILES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getTHRESHOLD_KEY() { return (java.lang.String)null;}
public static  java.lang.String getEFFORT_KEY() { return (java.lang.String)null;}
public static  java.lang.String getDETAILSLINK_KEY() { return (java.lang.String)null;}
public static  java.lang.String getVERSIONTITLE_KEY() { return (java.lang.String)null;}
public static  java.lang.String getSUMMARY_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CLASS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_CLASSES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_ERRORS_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_FILES_KEY() { return (java.lang.String)null;}
public static  java.lang.String getCOLUMN_MISSINGCLASSES_KEY() { return (java.lang.String)null;}
public  org.apache.maven.doxia.sink.Sink getSink() { return (org.apache.maven.doxia.sink.Sink)null;}
public  void setSink(org.apache.maven.doxia.sink.Sink value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  org.apache.maven.plugin.logging.Log getLog() { return (org.apache.maven.plugin.logging.Log)null;}
public  void setLog(org.apache.maven.plugin.logging.Log value) { }
public  java.lang.String getThreshold() { return (java.lang.String)null;}
public  void setThreshold(java.lang.String value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.String getCurrentClassName() { return (java.lang.String)null;}
public  void setCurrentClassName(java.lang.String value) { }
public  boolean getmIsCurrentClassReportOpened() { return false;}
public  boolean ismIsCurrentClassReportOpened() { return false;}
public  void setmIsCurrentClassReportOpened(boolean value) { }
public  boolean getIsJXRReportEnabled() { return false;}
public  boolean isIsJXRReportEnabled() { return false;}
public  void setIsJXRReportEnabled(boolean value) { }
public  int getBugCount() { return (int)0;}
public  void setBugCount(int value) { }
public  int getMissingClassCount() { return (int)0;}
public  void setMissingClassCount(int value) { }
public  int getFileCount() { return (int)0;}
public  void setFileCount(int value) { }
public  java.util.Set getMissingClassSet() { return (java.util.Set)null;}
public  void setMissingClassSet(java.util.Set value) { }
public  int getErrorCount() { return (int)0;}
public  void setErrorCount(int value) { }
public  java.io.File getOutputDirectory() { return (java.io.File)null;}
public  void setOutputDirectory(java.io.File value) { }
public  java.io.File getXrefLocation() { return (java.io.File)null;}
public  void setXrefLocation(java.io.File value) { }
public  java.io.File getXrefTestLocation() { return (java.io.File)null;}
public  void setXrefTestLocation(java.io.File value) { }
public  java.util.List getCompileSourceRoots() { return (java.util.List)null;}
public  void setCompileSourceRoots(java.util.List value) { }
public  java.util.List getTestSourceRoots() { return (java.util.List)null;}
public  void setTestSourceRoots(java.util.List value) { }
public  boolean getIncludeTests() { return false;}
public  boolean isIncludeTests() { return false;}
public  void setIncludeTests(boolean value) { }
public  org.apache.maven.doxia.tools.SiteTool getSiteTool() { return (org.apache.maven.doxia.tools.SiteTool)null;}
public  void setSiteTool(org.apache.maven.doxia.tools.SiteTool value) { }
public  java.io.File getBasedir() { return (java.io.File)null;}
public  void setBasedir(java.io.File value) { }
public  groovy.xml.slurpersupport.GPathResult getSpotbugsResults() { return (groovy.xml.slurpersupport.GPathResult)null;}
public  void setSpotbugsResults(groovy.xml.slurpersupport.GPathResult value) { }
public  java.util.List getBugClasses() { return (java.util.List)null;}
public  void setBugClasses(java.util.List value) { }
public  void printBody() { }
protected  void printBug(java.lang.String bugClass) { }
protected  java.lang.String assembleJxrHyperlink(groovy.xml.slurpersupport.GPathResult line) { return (java.lang.String)null;}
protected  java.lang.String getReportTitle() { return (java.lang.String)null;}
protected  void openClassReportSection(java.lang.String bugClass) { }
protected  void printSummary() { }
protected  void printFilesSummary() { }
public  void generateReport() { }
protected  java.lang.String valueForLine(groovy.xml.slurpersupport.GPathResult line) { return (java.lang.String)null;}
}
